#ifndef PLUGINLOADERTHREAD_H
#define PLUGINLOADERTHREAD_H

#include <QThread>
#include "maemobarcodewindow.h"
#include <QPluginLoader>
#include <QDir>

class ResultsWindow;

class PluginLoaderThread : public QThread
{
    Q_OBJECT
public:
    PluginLoaderThread(MaemoBarcodeWindow *mainWindow);
    void run();

private:
    MaemoBarcodeWindow *w;

private slots:
    void loadPlugins();
};




#endif // PLUGINLOADERTHREAD_H
